@@ -436,7 +436,11 @@ oom:
 	 */
 	{
 		static unsigned long cs_last_oom;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 19, 0)
 		unsigned long oom = get_seconds();
+#else
+		unsigned long oom = ktime_get_real_seconds();
+#endif
 
 		if (oom != cs_last_oom) {
 			cs_last_oom = oom;
