@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.7   2020/08/20
+ * Version: 0.2.8   2020/11/11
  */
 
 #include "caitsith.h"
@@ -12,6 +12,9 @@
 #include <linux/nsproxy.h>
 #include <linux/mnt_namespace.h>
 #endif
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 8, 0)
+#include <linux/proc_fs.h>
+#endif
 
 /***** SECTION1: Constants definition *****/
 
@@ -326,6 +329,15 @@ static char *cs_get_local_path(struct dentry *dentry, char * const buffer,
 		char *ep;
 		const pid_t pid = (pid_t) simple_strtoul(pos + 1, &ep, 10);
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 8, 0)
+		if (*ep == '/' && pid && pid ==
+		    task_tgid_nr_ns(current, proc_pid_ns(sb))) {
+			pos = ep - 5;
+			if (pos < buffer)
+				goto out;
+			memmove(pos, "/self", 5);
+		}
+#else
 		if (*ep == '/' && pid && pid ==
 		    task_tgid_nr_ns(current, sb->s_fs_info)) {
 			pos = ep - 5;
@@ -333,6 +345,7 @@ static char *cs_get_local_path(struct dentry *dentry, char * const buffer,
 				goto out;
 			memmove(pos, "/self", 5);
 		}
+#endif
 		goto prepend_filesystem_name;
 	}
 	/* Use filesystem name for unnamed devices. */
